__version__ = '0.1.0'


""" Top level package for the detect_and_display """

__author__ = """ Patricio Tula and Agustin Tedesco """
__version__ = '0.1.0'

from detect_and_display.detect_and_display import DetectAndDisplay

__all__ = ['DetectAndDisplay']
