class DetectAndDisplay:
    """Class that encapsulates the detection and display of license plates."""
    def display(self, text: str) -> None:
        """Display the text"""
        return f'the screen is displaying: {text}'
